;-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
; LayerStatus
;
; LAYERSTATUS speichert kurzzeitig den Layerstand einer Zeichnung. So
; werden schnell die Eigenschaften EIN/AUS, GEFROREN/GETAUT und
; GESPERRT/ENTSPERRT zwischengespeichert, um zwischendurch etwas anderes
; einstellen zu knnen.
;
; Aufruf: layerst
;-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
; (c) Dipl.-Ing.  Volker Kleppel
; http://www.cadwerk.com
; vkleppel@gmx.de
;-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
; Version: 1.1                      Datum: 20.05.2018
; AutoCAD12   [ ]  AutoCAD14   [x]  AutoCAD2000(i) [x]   
; AutoCAD2002 [x]  AutoCAD2004 [x]  AutoCAD2005    [x]
; AutoCAD2006 [x]  AutoCAD2007 [x]  AutoCAD2008    [x]
; AutoCAD2009 [x]  AutoCAD2010 [x]  AutoCAD2011    [x]
; AutoCAD2012 [x]  AutoCAD2013 [x]  AutoCAD2014    [x]
; AutoCAD2015 [x]  AutoCAD2016 [x]  AutoCAD2017    [x]
; AutoCAD2018 [x]  AutoCAD2019 [x]
; Freeware    [x]  Shareware   [ ]
;-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

;;-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
;; LAYERSTATUS
;;
;; Programm sichert den aktuellen Layerstand oder schreibt den gesichrten Layerstand wieder zurck. Die variable,
;; in die gesichert wird kann vom Benutzer nicht vorgegeben werden - auch hat diese Routine nichts mit den
;; Bonustools 'LMAN' zu tun.
;;
;; Die beiden Modi (Auto/Manuell) unterscheiden sich darin, das der Benutzer bei 'Manuell' selber auswhlen mu,
;; ob er nun Sichern oder Wiederherstellen will - dieses bei 'Auto' jenachdem vorgeschlagen wird
;;
;; Dezember 1998
;; Letzte nderung: 22.1.1999
;;-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

(defun c:layerst ()
	(if (not layersteinst) (setq layersteinst "Auto"))

	(if (= layersteinst "Auto")
		(progn
			(princ "\nModus: Automatisch")
			(if (= layerlisteflip T)
				(progn
					(initget 128 "Sichern Wiederherstellen Einstellung")
					(if (not (setq answer (getkword "\nLayerstatus: Einstellung/Sichern/<Wiederherstellen> "))) (setq answer "Wiederherstellen"))
				)
				(progn
					(initget 128 "Sichern Wiederherstellen Einstellung")
					(if (not (setq answer (getkword "\nLayerstatus: Einstellung/Wiederherstellen/<Sichern> ")))  (setq answer "Sichern"))
				)
			)
		)
		(progn
			(princ "\nModus: Manuell")
			(initget 128 "Sichern Wiederherstellen Einstellung")
			(if (not (setq answer (getkword "\nLayerstatus: Einstellung/Sichern/<Wiederherstellen> "))) (setq answer "Wiederherstellen"))
		)
	)

	;Einstellung
	(if (= answer "Einstellung")
		(progn
			(initget 128 "Manuell Auto")
			(if (not (setq layersteinst (getkword "\nEinstellung: Manuell/<Auto> "))) (setq layersteinst "Auto"))
			(print)
		)
	)

	;Wiederherstellen
	(if (= answer "Wiederherstellen")
		(progn
		(if (not layerstliste) (princ "\nKeinen Layerstand gesichert!")	(layerwiederherstellen))
		(setq layerlisteflip nil)
		)
	)

	;Sichern
	(if (= answer "Sichern")
		(layersichern)
	)	

	(print)
)

(defun layersichern ()
		(setq layerliste nil)
		(setq dump (tblnext "LAYER" T))
		(while (/= dump nil)
			(setq layerstliste (append layerstliste (list dump)))
			(setq dump (tblnext "layer"))
		)
		(setq layerlisteflip T)
		(princ "\nLayerstauts wurde gesichert")
		(print)
)

(defun layerwiederherstellen ( / dump regendump)
		(setq i (length layerstliste) regendump nil)
		(while (> i 0)
			(setq temp (nth (1- i) layerstliste))
			(setq en (tblobjname "LAYER" (cdr (assoc 2 temp))))
			(setq ent (entget en))
			(if (= (boole 1 1 (cdr (assoc 70 temp))) 1) (setq regendump T))
			(setq ent (subst (assoc 70 temp) (assoc 70 ent) ent))
			(setq ent (subst (assoc 62 temp) (assoc 62 ent) ent))
			(entmod ent)
			(entupd en)
			(setq i (1- i))
		)

		(setq dump (getvar "CMDECHO"))
		(setvar "cmdecho" 0)
		(command "_.layer" "")
		(setvar "cmdecho" dump)
		(if (= regendump T) (progn (command "_regenall") (princ "\nZeichnung mu regeneriert werden ...")))
		(princ "\nLayerstatus wurde wiederhergestellt")
		(print)
)

(princ "\nLayerStatus - (c) Dipl.-Ing. V. Kleppel, www.cadwerk.com")
(princ "\nAufruf: layerst")
(print)